@@ -6,11 +6,12 @@ from django.conf import settings
 class OcppConfig(AppConfig):
     default_auto_field = "django.db.models.BigAutoField"
     name = "ocpp"
-    verbose_name = "OCPP"
+    verbose_name = "3. Protocol"
 
     def ready(self):  # pragma: no cover - startup side effects
-        lock = Path(settings.BASE_DIR) / "locks" / "control.lck"
-        if not lock.exists():
+        control_lock = Path(settings.BASE_DIR) / "locks" / "control.lck"
+        rfid_lock = Path(settings.BASE_DIR) / "locks" / "rfid.lck"
+        if not (control_lock.exists() and rfid_lock.exists()):
             return
         from .rfid.background_reader import start
         from .rfid.signals import tag_scanned
