@@ -172,10 +172,12 @@ for key, val in _load_state_file().items():  # pragma: no cover - simple load
 async def simulate_cp(
     cp_idx: int,
     host: str,
-    ws_port: int,
+    ws_port: Optional[int],
     rfid: str,
     vin: str,
     cp_path: str,
+    serial_number: str,
+    connector_id: int,
     duration: int,
     kw_min: float,
     kw_max: float,
@@ -194,7 +196,10 @@ async def simulate_cp(
     if the server closes the connection.
     """
 
-    uri = f"ws://{host}:{ws_port}/{cp_path}"
+    if ws_port:
+        uri = f"ws://{host}:{ws_port}/{cp_path}"
+    else:
+        uri = f"ws://{host}/{cp_path}"
     headers = {}
     if username and password:
         userpass = f"{username}:{password}"
@@ -273,6 +278,7 @@ async def simulate_cp(
                         {
                             "chargePointModel": "Simulator",
                             "chargePointVendor": "SimVendor",
+                            "serialNumber": serial_number,
                         },
                     ]
                 )
@@ -310,7 +316,7 @@ async def simulate_cp(
                                     "meter",
                                     "MeterValues",
                                     {
-                                        "connectorId": 1,
+                                        "connectorId": connector_id,
                                         "meterValue": [
                                             {
                                                 "timestamp": time.strftime(
@@ -364,6 +370,7 @@ async def simulate_cp(
                     {
                         "chargePointModel": "Simulator",
                         "chargePointVendor": "SimVendor",
+                        "serialNumber": serial_number,
                     },
                 ]
             )
@@ -401,7 +408,7 @@ async def simulate_cp(
                                 "meter",
                                 "MeterValues",
                                 {
-                                    "connectorId": 1,
+                                    "connectorId": connector_id,
                                     "meterValue": [
                                         {
                                             "timestamp": time.strftime(
@@ -431,7 +438,7 @@ async def simulate_cp(
                     "start",
                     "StartTransaction",
                     {
-                        "connectorId": 1,
+                        "connectorId": connector_id,
                         "idTag": rfid,
                         "meterStart": meter_start,
                         "vin": vin,
@@ -459,7 +466,7 @@ async def simulate_cp(
                         "meter",
                         "MeterValues",
                         {
-                            "connectorId": 1,
+                            "connectorId": connector_id,
                             "transactionId": tx_id,
                             "meterValue": [
                                 {
@@ -522,7 +529,7 @@ async def simulate_cp(
                             "meter",
                             "MeterValues",
                             {
-                                "connectorId": 1,
+                                "connectorId": connector_id,
                                 "meterValue": [
                                     {
                                         "timestamp": time.strftime("%Y-%m-%dT%H:%M:%S")
@@ -578,10 +585,12 @@ async def simulate_cp(
 def simulate(
     *,
     host: str = "127.0.0.1",
-    ws_port: int = 9000,
+    ws_port: Optional[int] = 8000,
     rfid: str = "FFFFFFFF",
     cp_path: str = "CPX",
     vin: str = "",
+    serial_number: str = "",
+    connector_id: int = 1,
     duration: int = 600,
     kw_min: float = 30.0,
     kw_max: float = 60.0,
@@ -614,6 +623,8 @@ def simulate(
         "rfid": rfid,
         "cp_path": cp_path,
         "vin": vin,
+        "serial_number": serial_number,
+        "connector_id": connector_id,
         "duration": duration,
         "kw_min": kw_min,
         "kw_max": kw_max,
@@ -642,6 +653,8 @@ def simulate(
                 rfid,
                 vin,
                 this_cp_path,
+                serial_number,
+                connector_id,
                 duration,
                 kw_min,
                 kw_max,
@@ -662,6 +675,8 @@ def simulate(
                     rfid,
                     vin,
                     this_cp_path,
+                    serial_number,
+                    connector_id,
                     duration,
                     kw_min,
                     kw_max,
@@ -712,6 +727,8 @@ def simulate(
                 rfid,
                 vin,
                 cp_path,
+                serial_number,
+                connector_id,
                 duration,
                 kw_min,
                 kw_max,
@@ -736,6 +753,8 @@ def simulate(
                     rfid,
                     vin,
                     this_cp_path,
+                    serial_number,
+                    connector_id,
                     duration,
                     kw_min,
                     kw_max,
@@ -850,7 +869,9 @@ def _simulator_status_json(cp: Optional[int] = None) -> str:
 
     if cp is not None:
         return json.dumps(_export_state(_simulators[cp]), indent=2)
-    return json.dumps({str(idx): _export_state(st) for idx, st in _simulators.items()}, indent=2)
+    return json.dumps(
+        {str(idx): _export_state(st) for idx, st in _simulators.items()}, indent=2
+    )
 
 
 def get_simulator_state(cp: Optional[int] = None, refresh_file: bool = False):
@@ -908,4 +929,3 @@ __all__ = [
     "view_cp_simulator",
     "view_simulator",
 ]
-
