@@ -2,6 +2,8 @@ import os
 import sys
 from pathlib import Path
 
+import pytest
+
 sys.path.append(str(Path(__file__).resolve().parent.parent))
 os.environ.setdefault("DJANGO_SETTINGS_MODULE", "config.settings")
 import django
@@ -13,6 +15,9 @@ from django.urls import reverse
 from django.contrib.auth import get_user_model
 
 
+pytestmark = [pytest.mark.feature("rfid-scanner")]
+
+
 class AdminRfidScanCsrfTests(TestCase):
     def setUp(self):
         User = get_user_model()
